@@ -8,6 +8,7 @@ use Number::Format;
 use overload 
     '+'  => \&pv_add,
     '*'  => \&pv_mul,
+    '**' => \&pv_mulmul,
     '-'  => \&pv_sub,
     '/'  => \&pv_div,
     '++' => \&pv_inc,
@@ -20,7 +21,7 @@ use overload
     'eq' => \&pv_str_eq,
     '""' => \&pv_print;
 
-our $VERSION        = "0.45";
+our $VERSION        = "0.46";
 our $StrictTypes    = 0; # throws errors on unknown units
 our $PrintPrecision = 2; 
 our $fmt;
@@ -111,6 +112,20 @@ sub pv_mul {
     return bless [ $v, $u ], ref $lhs;
 }
 # }}}
+# pv_mulmul {{{
+sub pv_mulmul {
+    my ($lhs, $rhs) = @_; 
+
+    croak "right hand side must be a scalar (ie no units)" if ref($rhs);
+
+    my ($v, $u) = (@$lhs);
+
+    $v = $v ** $rhs;
+    $u = $u ** $rhs;
+
+    return bless [ $v, $u ], ref $lhs;
+}
+# }}}
 # pv_div {{{
 sub pv_div {
     my ($lhs, $rhs) = @_;
@@ -516,6 +531,7 @@ use overload
     '-'  => \&au_sub,
     '/'  => \&au_div,
     '*'  => \&au_mul,
+    '**' => \&au_mulmul,
     'eq' => \&au_eq,
     '""' => \&au_print;
 
@@ -564,6 +580,15 @@ sub au_mul {
     return bless { unit=>($lhs->{unit} * $rhs->{unit}) }, ref $lhs;
 }
 # }}}
+# au_mulmul {{{
+sub au_mulmul {
+    my ($lhs, $rhs) = @_;
+
+    croak "right hand side must be a scalar" if ref($rhs);
+
+    return bless { unit=>($lhs->{unit} ** $rhs) }, ref $lhs;
+}
+# }}}
 # au_div {{{
 sub au_div {
     my ($lhs, $rhs) = @_;
